CodeMirror: Language Modes

## Language modes

This is a list of every mode in the distribution. Each mode lives in a subdirectory of the `mode/` directory, and typically defines a single JavaScript file that implements the mode. Loading such file will make the language available to CodeMirror, through the `mode` option.

- APL
- Asterisk dialplan
- C, C++, C#
- Clojure
- COBOL
- CoffeeScript
- Common Lisp
- CSS
- Cypher
- Cython
- D
- Django (templating language)
- Dockerfile
- diff
- DTD
- Dylan
- ECL
- Eiffel
- Erlang
- Fortran
- F#
- Gas (AT&T-style assembly)
- Gherkin
- Go
- Groovy
- HAML
- Haskell
- Haxe
- HTML embedded scripts
- HTML mixed-mode
- HTTP
- IDL
- Java
- Jade
- JavaScript
- Jinja2
- Julia
- Kotlin
- LESS
- LiveScript
- Lua
- Markdown (GitHub-flavour)
- mIRC
- Modelica
- Nginx
- NTriples
- Objective C
- OCaml
- Octave (MATLAB)
- Pascal
- PEG.js
- Perl
- PHP
- Pig Latin
- Properties files
- Puppet
- Python
- Q
- R
- RPM
- reStructuredText
- Ruby
- Rust
- Sass
- Scala
- Scheme
- SCSS
- Shell
- Sieve
- Slim
- Smalltalk
- Smarty
- Smarty/HTML mixed
- Solr
- SQL (several dialects)
- SPARQL
- sTeX, LaTeX
- Tcl
- Textile
- Tiddlywiki
- Tiki wiki
- TOML
- Tornado (templating language)
- Turtle
- VB.NET
- VBScript
- Velocity
- Verilog/SystemVerilog
- XML/HTML
- XQuery
- YAML
- Z80